      subroutine count_pl(npivots,allocated,fibstatus,nop,nsp,
     :   nfp,ncp)
C+------------------------------------------------------------------------------
C
C     Name:   
C        count_pl
C
C     Invocation:
C        call count_pl(npivots,allocated,fibstatus,nop,nsp,nfp,ncp)
C
C     Description:
C        The number of objects of each class (program, sky, fiducial,
C        and cursor-placed) is counted.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        npivots:  Integer (>)
C           Number of fibre pivots
C        allocated:  Integer array (>)
C           Array of values which give the reference numbers of the objects
C           allocated to each fibre.
C        fibstatus:  Integer array (>)
C           Array of values which gives the fibre type for each pivot
C           (i.e. fiducial, object, disabled, etc).
C        nop:  Integer (<)
C           The number of program objects placed
C        nsp:  Integer (<)
C           The number of sky patches placed
C        nfp:  Integer (<)
C           The number of fiducial objects placed
C        ncp:  Integer (<)
C           The number of fibres placed by cursor position
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        none
C 
C     Algorithm:
C        -- The array 'allocated' is examined for each pivot.
C        -- If its value is equal to 'alloc_cur' then this is a cursor
C           placed fibre.
C        -- If its value is greater than 'alloc_sky' then this is a sky
C           patch 
C        -- Otherwise if it's greater than zero it is either a program
C           object or a fiducial object.  We look at the array 'fibstatus'
C           to determine whether it's a program or a fiducial object.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
      include 'AF2_FSTA.INC'
C
C     Parameters
C
      integer npivots
      integer allocated(npivots)
      integer fibstatus(npivots)
      integer nop
      integer nsp
      integer nfp
      integer ncp
C
C     Local variables
C
      integer i
C
C     Initialise the counters
C
      nop = 0
      nsp = 0
      nfp = 0
      ncp = 0
C
C     Now loop for the pivots and see how many there are of each type
C
      do 10 i = 1,npivots
         if (allocated(i) .eq. alloc_cur) then
            ncp = ncp + 1
         else if (allocated(i) .gt. alloc_sky) then
            nsp = nsp + 1
         else if (allocated(i) .gt. 0) then
            if (fibstatus(i) .eq. fsta_fok) then
               nfp = nfp + 1
            else if (fibstatus(i) .eq. fsta_ook) then
               nop = nop + 1
            end if
         end if
  10  continue
C
C     Exit
C
      end
