#include <stdio.h>
#include <stdlib.h>
#include "af2_par.h"

#ifdef REMOVE_CSUB_UNDERSCORE
void csub_rename_(oname,oname_length,nname,nname_length,status)
#else
void csub_rename__(oname,oname_length,nname,nname_length,status)
#endif
/*----------------------------------------------------------------------------*/
/*                                                                            */
/*    Name:                                                                   */
/*       csub_rename_                                                         */
/*                                                                            */
/*    Invocation:                                                             */
/*       call csub_rename(oname,oname_length,nname,nname_length,status)       */
/*                                                                            */
/*    Description:                                                            */
/*       Rename a file                                                        */
/*                                                                            */
/*    Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)         */
/*       oname:  Char* (>)                                                    */
/*          The FORTRAN character string with the old name of the file        */
/*       oname_length:  Int* (>)                                              */
/*          The length of the old name string                                 */
/*       nname:  Char* (>)                                                    */
/*          The FORTRAN character string with the new name of the file        */
/*       nname_length:  Int* (>)                                              */
/*          The length of the new name string                                 */
/*       status:  Int* (!)                                                    */
/*          The global status variable                                        */
/*                                                                            */
/*    Language:                                                               */
/*       ANSI C                                                               */
/*                                                                            */
/*    Non-standard language extensions:                                       */
/*       None                                                                 */
/*                                                                            */
/*    Algorithm:                                                              */
/*       -- Find the last non-blank character in the FORTRAN string and       */
/*          allocate workspace to copy the non-blank bit into.                */
/*       -- Copy the FORTRAN string over and use the intrinsic rename         */
/*          to rename the file                                                */
/*       -- Free the workspace and exit                                       */
/*                                                                            */
/*    Authors:                                                                */
/*       (JRL): James R. Lewis -- RGO, Cambridge                              */
/*                                                                            */
/*    History:                                                                */
/*       02 Sep 1996 (JRL):                                                   */
/*          Original version                                                  */
/*                                                                            */
/*----------------------------------------------------------------------------*/

/* Parameters */
char *const oname;
int *const oname_length;
char *const nname;
int *const nname_length;
int *const status;

{

      /* Local variables */
      int i1,i2,j;
      char *ptr1,*ptr2;

      /* Inherited status */
      if (*status != AF2_OK) return;

      /* Locate the last non-blank character in input FORTRAN string */
      /* Don't forget the the first element is actually 0 not 1 */
      for (i1 = *oname_length - 1; i1 >= 0 && oname[i1] == ' '; i1--)
         ;
      for (i2 = *nname_length - 1; i2 >= 0 && nname[i2] == ' '; i2--)
         ;

      /* Get some space for a copy of the input string (plus one extra */
      /* for the EOS marker) */
      ptr1 = (char *)malloc((size_t)(i1+2));
      ptr2 = (char *)malloc((size_t)(i2+2));

      /* If the null pointer came up, then signal an error */
      if (ptr1 == 0) {
         fprintf(stderr,"Couldn't allocate %d bytes in RENAME\n",i1+2);
         *status = AF2_ERR;
         return;
      } else if (ptr2 == 0) {
         fprintf(stderr,"Couldn't allocate %d bytes in RENAME\n",i2+2);
         *status = AF2_ERR;
         return;
      }

      /* Otherwise copy the string over...*/
      ptr1[i1+1] = '\0';
      for (; i1 >= 0; i1--)
         ptr1[i1] = oname[i1];
      ptr2[i2+1] = '\0';
      for (; i2 >= 0; i2--)
         ptr2[i2] = nname[i2];

      /* Ok, now get the environment name */
      j = rename(ptr1,ptr2);

      /* If the pointer came out null, then signal an error */
      if (j != 0) {
         fprintf(stderr,"Can't do rename: %s --> %s \n",ptr1,ptr2);
         *status = AF2_ERR;
         return;
      }

      /* Free workspace */
      free((void *)ptr1);
      free((void *)ptr2);
}
