      SUBROUTINE sla__ATMT (R0, T0, ALPHA, GAMM2, DELM2,
     :                      C1, C2, C3, C4, C5, C6, R, T, DN, DNDR)
*+
*     - - - - -
*      A T M T
*     - - - - -
*
*  Internal routine used by REFRO
*
*  Refractive index and derivative wrt height for the troposphere
*
*  Given:
*    R0      d    height of observer from centre of the Earth (metre)
*    T0      d    temperature at the observer (deg K)
*    ALPHA   d    alpha          )
*    GAMM2   d    gamma minus 2  ) see HMNAO paper
*    DELM2   d    delta minus 2  )
*    C1      d    useful term  )
*    C2      d    useful term  )
*    C3      d    useful term  ) see source
*    C4      d    useful term  ) of sla_REFRO
*    C5      d    useful term  )
*    C6      d    useful term  )
*    R       d    current distance from the centre of the Earth (metre)
*
*  Returned:
*    T       d    temperature at R (deg K)
*    DN      d    refractive index at R
*    DNDR    d    rate the refractive index is changing at R
*
*  This routine is a version of the ATMOSTRO routine (C.Hohenkerk,
*  HMNAO), with enhancements, specified by A.T.Sinclair (RGO) to
*  handle the radio case.
*
*  Note that in the optical case C5 and C6 are zero.
*
*  Original version by C.Hohenkerk, HMNAO, August 1984
*  This Starlink version by P.T.Wallace, 26 July 1993
*-

      IMPLICIT NONE

      DOUBLE PRECISION R0,T0,ALPHA,GAMM2,DELM2,C1,C2,C3,C4,C5,C6,
     :                 R,T,DN,DNDR

      DOUBLE PRECISION TT0,TT0GM2,TT0DM2


      T = T0-ALPHA*(R-R0)
      TT0 = MAX(T/T0,0D0)
      TT0GM2 = TT0**GAMM2
      TT0DM2 = TT0**DELM2
      DN = 1D0+(C1*TT0GM2-(C2-C5/T)*TT0DM2)*TT0
      DNDR = -C3*TT0GM2+(C4-C6/TT0)*TT0DM2

      END
